@@ -27,6 +27,7 @@
 
 import datetime
 import hubzero.config.passwords
+import hubzero.config.webconfig
 import hubzero.data.db
 import ldap
 import ldap.modlist
@@ -115,27 +116,15 @@ def _insert_jos_xprofiles(db, uid, fname, lname, username, email, joomlagid, joo
 	db.execQuery(sql, data)
 
 
+def _insert_jos_users_password(db, userid, pw):
+	sql = "INSERT INTO jos_users_password (`user_id`, `passhash`) " 
+	sql += "VALUES (%s, %s)"
+	
+	data = (userid, hubzero.config.passwords.MD5PasswordHash(pw))
+	db.execQuery(sql, data)
+
+
 def _insert_jos_xgroups(db, name, description):
-	"""	
-	cn                             | varchar(255) | YES  | 
-	description                    | varchar(255) | YES  | 
-	published                      | tinyint(3)   | YES  | 
-	type                           | tinyint(3)   | YES  | 
-	access                         | tinyint(3)   | YES  | 
-	public_desc                    | text         | YES  | 
-	private_desc                   | text         | YES  | 
-	restrict_msg                   | text         | YES  | 
-	join_policy                    | tinyint(3)   | YES  | 
-	privacy                        | tinyint(3)   | YES  | 
-	discussion_email_autosubscribe | tinyint(3)   | YES  | 
-	logo                           | varchar(255) | YES  | 
-	overview_type                  | int(11)      | YES  | 
-	overview_content               | text         | YES  | 
-	plugins                        | text         | YES  | 
-	created                        | datetime     | YES  | 
-	created_by                     | int(11)      | YES  | 
-	params                         | text 	
-	"""
 	sql =  "INSERT INTO jos_xgroups ( `cn`, `description`, `published`, `type`, `access`, `public_desc`, `private_desc`, `restrict_msg`, "
 	sql += "`join_policy`, `privacy`, `discussion_email_autosubscribe`, `logo`, `overview_type`, `overview_content`, `plugins`, `created`,"
 	sql += "`created_by`, `params`) " 
@@ -186,7 +175,6 @@ def _del_ldap_group(groupName):
 	l.delete_s(dn)
 
 
-
 def _add_ldap_user(username, password):
 
 	# get ldapManagerUserDN and PW
@@ -254,9 +242,12 @@ def addhubuser(username, fname, lname, email, pw, joomlagid, joomlagidNumber, gi
 	aroID = _insert_jos_core_acl_aro(db, userID, fullname)
 	_insert_jos_core_acl_groups_aro_map(db, joomlagidNumber, aroID)
 	_insert_jos_xprofiles(db, userID, fname, lname, username, email, joomlagid, joomlagidNumber, gid, gidNumber)
+	_insert_jos_users_password(db, userID, pw)
+	
+	# TODO add password table entry
 	
 	if not skipldap:
-		_add_ldap_user(username, 'nopasswd')
+		_add_ldap_user(username, pw)
 
 	
 def delhubuser(username):
@@ -271,7 +262,3 @@ def delhubuser(username):
 	_del_jos_core_acl_groups_aro_map(db, aroID)
 	_del_jos_xprofiles(db, userID)	
 	_delete_ldap_user(username)
-	
-	
-				  
-                  
